@@ -43,7 +43,7 @@ sub config {
 sub _new {
     my ($proto, $dbo, $table) = @_;
     my $class = ref($proto) || $proto;
-    blessed $dbo and $dbo->isa('DBIx::DBO::Handle') or ouch 'Invalid DBO Object';
+    blessed $dbo and $dbo->isa('DBIx::DBO') or ouch 'Invalid DBO Object';
     (my $schema, $table, $_) = $dbo->table_info($table) or ouch 'No such table: '.$table;
     bless { %$_, Schema => $schema, Name => $table, DBO => $dbo, LastInsertID => undef }, $class;
 }
